@@ -1,8 +1,7 @@
 """Adds plugin items to homepage."""
 from nautobot.core.apps import HomePageItem, HomePagePanel
 
-from nautobot_firewall_models.models import Policy, PolicyRule, CapircaPolicy
-
+from nautobot_firewall_models.models import Policy, PolicyRule, CapircaPolicy, NATPolicy, NATPolicyRule
 
 layout = (
     HomePagePanel(
@@ -17,14 +16,6 @@ layout = (
                 description="Firewall Policies",
                 permissions=["nautobot_firewall_models.view_policy"],
             ),
-            HomePageItem(
-                name="Capirca Policies",
-                model=CapircaPolicy,
-                weight=150,
-                link="plugins:nautobot_firewall_models:capircapolicy_list",
-                description="Firewall Policies",
-                permissions=["nautobot_firewall_models.view_capircapolicy"],
-            ),
             HomePageItem(
                 name="Policy Rules",
                 model=PolicyRule,
@@ -33,6 +24,30 @@ layout = (
                 description="Firewall Policies",
                 permissions=["nautobot_firewall_models.view_policyrule"],
             ),
+            HomePageItem(
+                name="NAT Policies",
+                model=NATPolicy,
+                weight=300,
+                link="plugins:nautobot_firewall_models:natpolicy_list",
+                description="NAT Policies",
+                permissions=["nautobot_firewall_models.view_natpolicy"],
+            ),
+            HomePageItem(
+                name="NAT Policy Rules",
+                model=NATPolicyRule,
+                weight=400,
+                link="plugins:nautobot_firewall_models:natpolicyrule_list",
+                description="NAT Policies",
+                permissions=["nautobot_firewall_models.view_natpolicyrule"],
+            ),
+            HomePageItem(
+                name="Capirca Policies",
+                model=CapircaPolicy,
+                weight=150,
+                link="plugins:nautobot_firewall_models:capircapolicy_list",
+                description="Firewall Policies",
+                permissions=["nautobot_firewall_models.view_capircapolicy"],
+            ),
         ),
     ),
 )
